@@ -4,9 +4,9 @@ from multiprocessing import Process, Array
 
 import numpy as np
 from PyQt5.QtCore import pyqtSignal, QPoint, Qt, QMimeData, pyqtSlot, QTimer
-from PyQt5.QtGui import QFontDatabase, QIcon, QDrag, QPixmap, QRegion, QDropEvent, QTextCursor, QContextMenuEvent, \
+from PyQt5.QtGui import QIcon, QDrag, QPixmap, QRegion, QDropEvent, QTextCursor, QContextMenuEvent, \
     QResizeEvent
-from PyQt5.QtWidgets import QFrame, QMessageBox, QMenu, QWidget, QUndoStack, QCheckBox, QApplication
+from PyQt5.QtWidgets import QFrame, QMessageBox, QMenu, QWidget, QUndoStack, QCheckBox, QApplication, qApp
 
 from urh import constants
 from urh.controller.dialogs.AdvancedModulationOptionsDialog import AdvancedModulationOptionsDialog
@@ -266,6 +266,8 @@ class SignalFrame(QFrame):
                                                 self.ui.btnCloseSignal, self.ui.lineEditSignalName):
                 w.hide()
 
+        self.adjustSize()
+
     def cancel_filtering(self):
         self.filter_abort_wanted = True
 
@@ -283,7 +285,7 @@ class SignalFrame(QFrame):
             power_str = "-\u221e"  # minus infinity
             if start < end:
                 max_window_size = 10 ** 5
-                step_size = int(math.ceil((end-start)/max_window_size))
+                step_size = int(math.ceil((end - start) / max_window_size))
                 power = np.mean(np.abs(self.signal.data[start:end:step_size]))
                 if power > 0:
                     power_str = Formatter.big_value_with_suffix(10 * np.log10(power), 2)
@@ -740,6 +742,7 @@ class SignalFrame(QFrame):
 
             self.ui.gvSignal.auto_fit_view()
             self.ui.gvSignal.refresh_selection_area()
+            qApp.processEvents()
             self.on_slider_y_scale_value_changed()  # apply YScale to new view
             self.__set_samples_in_view()
             self.__set_duration()
@@ -748,8 +751,15 @@ class SignalFrame(QFrame):
 
     @pyqtSlot()
     def on_btn_autodetect_clicked(self):
-        self.signal.auto_detect(detect_modulation=self.detect_modulation_action.isChecked(),
-                                detect_noise=self.detect_noise_action.isChecked())
+        self.ui.btnAutoDetect.setEnabled(False)
+        self.setCursor(Qt.WaitCursor)
+        success = self.signal.auto_detect(detect_modulation=self.detect_modulation_action.isChecked(),
+                                          detect_noise=self.detect_noise_action.isChecked())
+        self.ui.btnAutoDetect.setEnabled(True)
+        self.unsetCursor()
+        if not success:
+            Errors.generic_error(self.tr("Autodetection failed"),
+                                 self.tr("Failed to autodetect parameters for this signal."))
 
     @pyqtSlot()
     def on_btn_replay_clicked(self):
@@ -988,6 +998,7 @@ class SignalFrame(QFrame):
         self.update_number_selected_samples()
 
         self.set_qad_tooltip(self.signal.noise_threshold)
+        self.on_slider_y_scale_value_changed()
 
     @pyqtSlot(float)
     def on_signal_qad_center_changed(self, qad_center):
@@ -1077,13 +1088,24 @@ class SignalFrame(QFrame):
 
     @pyqtSlot()
     def on_signal_data_changed_before_save(self):
-        font = self.ui.lineEditSignalName.font()  # type: QFont
+        font = self.ui.lineEditSignalName.font()
+        self.ui.gvSignal.auto_fit_on_resize_is_blocked = True
+
         if self.signal.changed:
             font.setBold(True)
             self.ui.btnSaveSignal.show()
         else:
             font.setBold(False)
             self.ui.btnSaveSignal.hide()
+            for i in range(self.undo_stack.count()):
+                cmd = self.undo_stack.command(i)
+                if isinstance(cmd, EditSignalAction):
+                    # https://github.com/jopohl/urh/issues/570
+                    cmd.signal_was_changed = True
+
+        qApp.processEvents()
+        self.ui.gvSignal.auto_fit_on_resize_is_blocked = False
+
         self.ui.lineEditSignalName.setFont(font)
 
     @pyqtSlot()
@@ -1228,7 +1250,7 @@ class SignalFrame(QFrame):
 
     @pyqtSlot(int)
     def on_message_length_divisor_edited(self, message_length_divisor: int):
-        if self.signal.pause_threshold != message_length_divisor:
+        if self.signal.message_length_divisor != message_length_divisor:
             message_length_divisor_action = ChangeSignalParameter(signal=self.signal, protocol=self.proto_analyzer,
                                                                   parameter_name="message_length_divisor",
                                                                   parameter_value=message_length_divisor)
@@ -1236,7 +1258,8 @@ class SignalFrame(QFrame):
 
     @pyqtSlot()
     def on_btn_advanced_modulation_settings_clicked(self):
-        dialog = AdvancedModulationOptionsDialog(self.signal.pause_threshold, self.signal.message_length_divisor, parent=self)
+        dialog = AdvancedModulationOptionsDialog(self.signal.pause_threshold, self.signal.message_length_divisor,
+                                                 parent=self)
         dialog.pause_threshold_edited.connect(self.on_pause_threshold_edited)
         dialog.message_length_divisor_edited.connect(self.on_message_length_divisor_edited)
         dialog.exec_()
